@@ -3,8 +3,8 @@ import sys
 import sys,os
 sys.path.append(os.getcwd())
 from gooey import Gooey, GooeyParser
-from common.comFuction import get_list
-from main_flow.main_flow import main_process
+from .common.comFuction import get_list
+from .main_flow.main_flow import main_process
 
 
 @Gooey(
